@@ -330,6 +330,12 @@ def increase_headings_offset(markdown: str, offset: int = 0):
     )
 
 
+def rstrip_trailing_newlines(content):
+    while content.endswith('\n') or content.endswith('\r'):
+        content = content.rstrip('\r\n')
+    return content
+
+
 def filter_paths(filepaths: list, ignore_paths: list = []):
     """Filters a list of paths removing those defined in other list of paths.
 
@@ -353,9 +359,13 @@ def filter_paths(filepaths: list, ignore_paths: list = []):
         # ignore by filepath
         if filepath in ignore_paths:
             continue
+
         # ignore by dirpath (relative or absolute)
         if (os.sep).join(filepath.split(os.sep)[:-1]) in ignore_paths:
             continue
-        response.append(filepath)
+
+        # ignore if is a directory
+        if not os.path.isdir(filepath):
+            response.append(filepath)
     response.sort()
     return response
